HandlerWithoutStateExt

Trait HandlerWithoutStateExt 

pub trait HandlerWithoutStateExt<T>: Handler<T, ()> {
    // Required methods
    fn into_service(self) -> HandlerService<Self, T, ()>;
    fn into_make_service(self) -> IntoMakeService<HandlerService<Self, T, ()>>;
    fn into_make_service_with_connect_info<C>(
        self,
    ) -> IntoMakeServiceWithConnectInfo<HandlerService<Self, T, ()>, C>;
}
Extension trait for Handlers that don’t have state.

This provides convenience methods to convert the Handler into a [Service] or MakeService.

Required Methods

fn into_service(self) -> HandlerService<Self, T, ()>

Convert the handler into a [Service] and no state.

fn into_make_service(self) -> IntoMakeService<HandlerService<Self, T, ()>>

Convert the handler into a MakeService and no state.

See HandlerService::into_make_service for more details.

fn into_make_service_with_connect_info<C>( self, ) -> IntoMakeServiceWithConnectInfo<HandlerService<Self, T, ()>, C>

Available on crate feature tokio only.

Convert the handler into a MakeService which stores information about the incoming connection and has no state.

See HandlerService::into_make_service_with_connect_info for more details.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors



impl<H, T> HandlerWithoutStateExt<T> for H
where H: Handler<T, ()>,